/*
 *   Show the bitmaps zero.b to ten.b.
 */

#include <stdio.h>
#include <X11/Xlib.h>
#include <X11/cursorfont.h>
#include <sys/types.h>
#include <math.h>

#include "zero.b"
#include "one.b"
#include "two.b"
#include "three.b"
#include "four.b"
#include "five.b"
#include "six.b"
#include "seven.b"
#include "eight.b"
#include "nine.b"
#include "ten.b"

#define FALSE 0
#define TRUE 1
#define DIM 20             /* Image is DIMxDIM (was 10). */
#define N 100              /* Max number of units allowed in net */

/*  X-related global variables */

Display              *disptr;
Window               win; 
XEvent               event;
GC                   gc;
XFontStruct          *font;
XGCValues            values;
XWindowAttributes    attr;
XSetWindowAttributes set_attr;
XImage               img, *subimg;
XColor               Grey[256];          /* Grey scale */
Pixmap               pmap;

static char *Bbits[] =
{
  zero_bits, one_bits, two_bits, three_bits, four_bits, five_bits,
  six_bits, seven_bits, eight_bits, nine_bits, ten_bits
};

static int Bwidth[] =
{
  zero_width, one_width, two_width, three_width, four_width, five_width,
  six_width, seven_width, eight_width, nine_width, ten_width
};

static int Bheight[] =
{
  zero_height, one_height, two_height, three_height, four_height, five_height,
  six_height, seven_height, eight_height, nine_height, ten_height
};

int Window_width;
int Window_height;

int X_off, Y_off;

main(argc,argv)
     int argc;
     char *argv[];
{
  int ing;                  /* Needed for command line parsing */
  extern char *optarg;      /* Needed for command line parsing */

  unsigned int seed;
  char state[256];
  long random();

  int i, j, epox, response;
  float RandomWeight();
  char inc;
  char printstring[20][80];

  int bitmap_size;

  int status;
  unsigned int *width_ret, *height_ret;
  int *x_hot_ret, *y_hot_ret;

  unsigned char BitmapBit();

  /* Read in options */

  while ((ing = getopt(argc,argv,"")) != EOF)
    switch (ing)
      {
      }

  /* Display the region selected */

  X_off = Bwidth[0];
  Y_off = Bheight[0];
  Window_width = (Bwidth[0] * DIM) + (2 * X_off);
  Window_height = (Bheight[0] * DIM) + (2 * Y_off);
  disptr=XOpenDisplay(NULL);
  if (!(font = XLoadQueryFont(disptr, "9x15")))
    {
      printf ("Error:  Cannot load font.\n");
      exit(1);
    }
  win=XCreateSimpleWindow(disptr,RootWindow(disptr,0), 50,100,
			  270, 50,
			  5,0,
			  WhitePixel(disptr,0));
  XStoreName(disptr,win,"Region Learning");
  XMapWindow(disptr,win);
  gc = DefaultGC(disptr, 0);

  XSelectInput(disptr, win, 
	       ButtonPressMask | KeyPressMask | ExposureMask );
  XNextEvent(disptr, &event);
  if (event.type != Expose)
    printf (">> Not expose event.\n");

  strcpy(printstring[0],  "Inappropriate   ");
  strcpy(printstring[1],  "       .        ");
  strcpy(printstring[2],  "       .        ");
  strcpy(printstring[3],  "       .        ");
  strcpy(printstring[4],  "       .        ");
  strcpy(printstring[5],  "       .        ");
  strcpy(printstring[6],  "       .        ");
  strcpy(printstring[7],  "       .        ");
  strcpy(printstring[8],  "       .        ");
  strcpy(printstring[9],  "       .        ");
  strcpy(printstring[10], "Very appropriate");

  for (j=0; j<=10; j++)
    {
/*
      XDrawImageString(disptr,win,gc, 45,(j+2)*Bheight[0]+2, 
		       printstring[j], 16);
*/
      DisplayValue((float)j/10.0, j, 0);
    }

  XFlush(disptr);

  pmap = XCreatePixmap(disptr,win,Window_width,Window_height,1);
  XCopyArea(disptr, win,pmap, gc, 0,0, 
	    Window_width,Window_height, 0,0);

  inc = 'c';
  while (inc != ' ')
    {
      XNextEvent(disptr, &event);
      if (event.type == KeyPress)
	XLookupString(&event, &inc, 1, NULL, NULL);
      else if (event.type == Expose)
	XCopyArea(disptr, pmap,win, gc, 0,0, 
		  Window_width,Window_height, 0,0);
    }
  
  XCloseDisplay( disptr );
}


/*
 *  Display the appropriate bitmap at the appropriate location.
 *    0 <= i,j < DIM.
 */
DisplayValue(val, x,y)
     float val;
     int x,y;
{
  Pixmap pmap;
  float fix;
  int stop, ix;
  char *bb;
  int  bw;
  int  bh;
  
  stop = FALSE;
  for (ix=0; ((ix<=10) && (stop == FALSE)); ix++)
    {
      fix = (float) ix / 10.0;
      if (fabs(val - fix) < 0.05)
	{
	  stop = TRUE;
	  bb = Bbits[ix];
	  bw = Bwidth[ix];
	  bh = Bheight[ix];
	}
    }
	
  pmap = XCreateBitmapFromData(disptr,win, bb, bw, bh);
  CenterPixmap((float)x/(float)DIM,(float)y/(float)DIM, pmap, bw);
  XFreePixmap(disptr, pmap);
}     


/*  
 *   Displays a pixmap, centered at x,y (0.0 <= x,y <= 1.0).
 */
CenterPixmap(fx,fy, pmap, size)
     float fx,fy;    /* coords to place center the pixmap at */
     Pixmap pmap;
     int size;     /* Width, height (assumed equal) of pmap */
{
  int x,y;

  x = ((int) (fx * (float) Window_width)) + X_off;
  y = ((int) (fy * (float) Window_height)) + Y_off;

  XCopyArea(disptr, pmap, win, gc, 0,0, size,size, x-(size/2), y-(size/2));
}

